@@ -210,7 +210,7 @@ def main():
                         help="Turns off calculation of mapping between canonical and PDB atom order for ligands.",
                         action="store_true")
     parser.add_argument("--dnareceptor", dest="dnareceptor", default=False,
-                        help="Uses the DNA instead of the protein as a receptor for interactions.",
+                        help="Treat nucleic acids as part of the receptor structure (together with any present protein) instead of as a ligand.",
                         action="store_true")
     parser.add_argument("--name", dest="outputfilename", default="report",
                         help="Set a filename for the report TXT and XML files. Will only work when processing single structures.")
@@ -225,6 +225,8 @@ def main():
     parser.add_argument("--nohydro", dest="nohydro", default=False,
                         help="Do not add polar hydrogens in case your structure already contains hydrogens.",
                         action="store_true")
+    parser.add_argument("--model", dest="model", default=1, type=int,
+                        help="Model number to be used for multi-model structures.")
     # Optional threshold arguments, not shown in help
     thr = namedtuple('threshold', 'name type')
     thresholds = [thr(name='aromatic_planarity', type='angle'),
@@ -275,6 +277,7 @@ def main():
     config.DNARECEPTOR = arguments.dnareceptor
     config.OUTPUTFILENAME = arguments.outputfilename
     config.NOHYDRO = arguments.nohydro
+    config.MODEL = arguments.model
     # Make sure we have pymol with --pics and --pymol
     if config.PICS or config.PYMOL:
         try:
